==> guikachu-1.3.7.tar.gz: guikachu-1.3.7/src/io/io.h <==
//$Id: io.h,v 1.4 2004/01/21 19:50:50 cactus Exp $ -*- c++ -*-

/* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2
 * as published by the Free Software Foundation.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

#ifndef GUIKACHU_IO_H
#define GUIKACHU_IO_H

#include "resource-manager.h"

#include <libgnomevfs/gnome-vfs.h>

namespace Guikachu
{
    namespace IO
    {
	typedef GnomeVFSResult IOResult;

	std::string create_canonical_uri (const std::string &filename);
	IOResult load_uri (const std::string &uri, char *&data, GnomeVFSFileSize &len);
	IOResult save_uri (const std::string &uri, const char *data, GnomeVFSFileSize len);
	
	class Loader
	{
	public:
	    virtual ~Loader () {};
	    
	    virtual IOResult load (ResourceManager *manager, const std::string &uri) = 0;
	};
	
	class Saver
	{
	public:
	    virtual ~Saver () {};
	    
	    virtual IOResult save (ResourceManager *manager, const std::string &uri) = 0;
	};
    }
}

#endif /* !GUIKACHU_IO_H */

==> guikachu-1.3.8.tar.gz: guikachu-1.3.8/src/io/io.h <==
//$Id: io.h,v 1.5 2004/03/20 23:46:09 cactus Exp $ -*- c++ -*-

/* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2
 * as published by the Free Software Foundation.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

#ifndef GUIKACHU_IO_H
#define GUIKACHU_IO_H

#include "resource-manager.h"

#include <libgnomevfs/gnome-vfs.h>

namespace Guikachu
{
    namespace IO
    {
	typedef GnomeVFSResult IOResult;

	std::string create_canonical_uri (const std::string &filename);
	IOResult load_uri (const std::string &uri, char *&data, GnomeVFSFileSize &len);
	IOResult save_uri (const std::string &uri, const char *data, GnomeVFSFileSize len);

	std::string get_mime_type (const std::string &uri);
	
	class Loader
	{
	public:
	    virtual ~Loader () {};
	    
	    virtual IOResult load (ResourceManager *manager, const std::string &uri) = 0;
	};
	
	class Saver
	{
	public:
	    virtual ~Saver () {};
	    
	    virtual IOResult save (ResourceManager *manager, const std::string &uri) = 0;
	};

	class IOFactory
	{
	    typedef Loader * (*loader_factory_fn) ();
	    typedef Saver *  (*saver_factory_fn) ();

	    typedef std::map<std::string, loader_factory_fn> loader_map_t;
	    typedef std::map<std::string, saver_factory_fn> saver_map_t;

	    loader_map_t loader_map;
	    saver_map_t  saver_map;
	    
	private:
	    IOFactory ();
	    static IOFactory *instance_;
	    
	public:
	    static IOFactory *instance ();
	    
	    Loader * create_loader (const std::string &mime_type) const;
	    Saver  * create_saver (const std::string &mime_type) const;
	};
    }
}

#endif /* !GUIKACHU_IO_H */
